@@ -15,7 +15,7 @@ async def test_making_and_inserting_models_in_bulk(aio_benchmark, num_models: in
         authors = [
             Author(
                 name="".join(random.sample(string.ascii_letters, 5)),
-                score=random.random() * 100,
+                score=int(random.random() * 100),
             )
             for i in range(0, num_models)
         ]
