@@ -1,34 +1,34 @@
 import databases
-import sqlalchemy
-
 import ormar
+import sqlalchemy
 
 database = databases.Database("sqlite:///db.sqlite")
 metadata = sqlalchemy.MetaData()
 
 
 class Course(ormar.Model):
-    class Meta:
-        database = database
-        metadata = metadata
+    ormar_config = ormar.OrmarConfig(
+        database=database,
+        metadata=metadata,
+    )
 
     id: int = ormar.Integer(primary_key=True)
     name: str = ormar.String(max_length=100)
     completed: bool = ormar.Boolean(default=False)
 
 
-print(Course.__fields__)
+print(Course.model_fields)
 """
 Will produce:
-{'id':        ModelField(name='id', 
+{'id':        Field(name='id', 
                          type=Optional[int], 
                          required=False, 
                          default=None),
- 'name':      ModelField(name='name', 
+ 'name':      Field(name='name', 
                          type=Optional[str], 
                          required=False, 
                          default=None),
-'completed':  ModelField(name='completed', 
+'completed':  Field(name='completed', 
                          type=bool, 
                          required=False, 
                          default=False)}
