@@ -3,11 +3,10 @@ Module with all decorators that are exposed for users.
 
 Currently only:
 
-* property_field - exposing @property like function as field in Model.dict()
 * predefined signals decorators (pre/post + save/update/delete)
 
 """
-from ormar.decorators.property_field import property_field
+
 from ormar.decorators.signals import (
     post_bulk_update,
     post_delete,
@@ -23,7 +22,6 @@ from ormar.decorators.signals import (
 )
 
 __all__ = [
-    "property_field",
     "post_bulk_update",
     "post_delete",
     "post_save",
