@@ -1,43 +1,41 @@
 from ormar.models.helpers.models import (
-    check_required_meta_parameters,
+    check_required_config_parameters,
+    config_field_not_set,
     extract_annotations_and_default_vals,
-    meta_field_not_set,
     populate_default_options_values,
 )
 from ormar.models.helpers.pydantic import (
     get_potential_fields,
     get_pydantic_base_orm_config,
-    get_pydantic_field,
     merge_or_generate_pydantic_config,
     remove_excluded_parent_fields,
 )
 from ormar.models.helpers.relations import (
     alias_manager,
+    expand_reverse_relationships,
     register_relation_in_alias_manager,
 )
-from ormar.models.helpers.relations import expand_reverse_relationships
 from ormar.models.helpers.sqlalchemy import (
-    populate_meta_sqlalchemy_table_if_required,
-    populate_meta_tablename_columns_and_pk,
+    populate_config_sqlalchemy_table_if_required,
+    populate_config_tablename_columns_and_pk,
     sqlalchemy_columns_from_model_fields,
 )
-from ormar.models.helpers.validation import populate_choices_validators
+from ormar.models.helpers.validation import modify_schema_example
 
 __all__ = [
     "expand_reverse_relationships",
     "extract_annotations_and_default_vals",
-    "populate_meta_tablename_columns_and_pk",
-    "populate_meta_sqlalchemy_table_if_required",
+    "populate_config_tablename_columns_and_pk",
+    "populate_config_sqlalchemy_table_if_required",
     "populate_default_options_values",
     "alias_manager",
     "register_relation_in_alias_manager",
-    "get_pydantic_field",
     "get_potential_fields",
     "get_pydantic_base_orm_config",
     "merge_or_generate_pydantic_config",
-    "check_required_meta_parameters",
+    "check_required_config_parameters",
     "sqlalchemy_columns_from_model_fields",
-    "populate_choices_validators",
-    "meta_field_not_set",
+    "config_field_not_set",
     "remove_excluded_parent_fields",
+    "modify_schema_example",
 ]
