@@ -1,4 +1,11 @@
-from typing import TYPE_CHECKING, Type, cast
+import inspect
+import warnings
+from typing import TYPE_CHECKING, Any, List, Optional, Type, Union, cast
+
+from pydantic import BaseModel, create_model, field_serializer
+from pydantic._internal._decorators import DecoratorInfos
+from pydantic.fields import FieldInfo
+from pydantic_core.core_schema import SerializerFunctionWrapHandler
 
 import ormar
 from ormar import ForeignKey, ManyToMany
@@ -9,7 +16,7 @@ from ormar.relations import AliasManager
 
 if TYPE_CHECKING:  # pragma no cover
     from ormar import Model
-    from ormar.fields import ManyToManyField, ForeignKeyField
+    from ormar.fields import ForeignKeyField, ManyToManyField
 
 alias_manager = AliasManager()
 
@@ -82,9 +89,13 @@ def expand_reverse_relationships(model: Type["Model"]) -> None:
     :param model: model on which relation should be checked and registered
     :type model: Model class
     """
-    model_fields = list(model.Meta.model_fields.values())
+    model_fields = list(model.ormar_config.model_fields.values())
     for model_field in model_fields:
-        if model_field.is_relation and not model_field.has_unresolved_forward_refs():
+        if (
+            model_field.is_relation
+            and not model_field.has_unresolved_forward_refs()
+            and not model_field.is_through
+        ):
             model_field = cast("ForeignKeyField", model_field)
             expand_reverse_relationship(model_field=model_field)
 
@@ -101,9 +112,9 @@ def register_reverse_model_fields(model_field: "ForeignKeyField") -> None:
     :type model_field: relation Field
     """
     related_name = model_field.get_related_name()
-    # TODO: Reverse relations does not register pydantic fields?
+    related_model_fields = model_field.to.ormar_config.model_fields
     if model_field.is_multi:
-        model_field.to.Meta.model_fields[related_name] = ManyToMany(  # type: ignore
+        related_model_fields[related_name] = ManyToMany(  # type: ignore
             model_field.owner,
             through=model_field.through,
             name=related_name,
@@ -122,7 +133,7 @@ def register_reverse_model_fields(model_field: "ForeignKeyField") -> None:
         register_through_shortcut_fields(model_field=model_field)
         adjust_through_many_to_many_model(model_field=model_field)
     else:
-        model_field.to.Meta.model_fields[related_name] = ForeignKey(  # type: ignore
+        related_model_fields[related_name] = ForeignKey(  # type: ignore
             model_field.owner,
             real_name=related_name,
             virtual=True,
@@ -133,9 +144,108 @@ def register_reverse_model_fields(model_field: "ForeignKeyField") -> None:
             skip_field=model_field.skip_reverse,
         )
     if not model_field.skip_reverse:
+        field_type = related_model_fields[related_name].__type__
+        field_type = replace_models_with_copy(
+            annotation=field_type, source_model_field=model_field.name
+        )
+        if not model_field.is_multi:
+            field_type = Union[field_type, List[field_type], None]  # type: ignore
+        model_field.to.model_fields[related_name] = FieldInfo.from_annotated_attribute(
+            annotation=field_type, default=None
+        )
+        add_field_serializer_for_reverse_relations(
+            to_model=model_field.to, related_name=related_name
+        )
+        model_field.to.model_rebuild(force=True)
         setattr(model_field.to, related_name, RelationDescriptor(name=related_name))
 
 
+def add_field_serializer_for_reverse_relations(
+    to_model: Type["Model"], related_name: str
+) -> None:
+    def serialize(
+        self: "Model", children: List["Model"], handler: SerializerFunctionWrapHandler
+    ) -> Any:
+        """
+        Serialize a list of nodes, handling circular references
+        by excluding the children.
+        """
+        try:
+            with warnings.catch_warnings():
+                warnings.filterwarnings(
+                    "ignore", message="Pydantic serializer warnings"
+                )
+                return handler(children)
+        except ValueError as exc:  # pragma: no cover
+            if not str(exc).startswith("Circular reference"):
+                raise exc
+
+            result = []
+            for child in children:
+                # If there is one circular ref dump all children as pk only
+                result.append({child.ormar_config.pkname: child.pk})
+            return result
+
+    decorator = field_serializer(related_name, mode="wrap", check_fields=False)(
+        serialize
+    )
+    setattr(to_model, f"serialize_{related_name}", decorator)
+    # DecoratorInfos.build will overwrite __pydantic_decorators__ on to_model,
+    # deleting the previous decorators. We need to save them and then merge them.
+    prev_decorators = getattr(to_model, "__pydantic_decorators__", DecoratorInfos())
+    new_decorators = DecoratorInfos.build(to_model)
+    prev_decorators.validators.update(new_decorators.validators)
+    prev_decorators.field_validators.update(new_decorators.field_validators)
+    prev_decorators.root_validators.update(new_decorators.root_validators)
+    prev_decorators.field_serializers.update(new_decorators.field_serializers)
+    prev_decorators.model_serializers.update(new_decorators.model_serializers)
+    prev_decorators.model_validators.update(new_decorators.model_validators)
+    prev_decorators.computed_fields.update(new_decorators.computed_fields)
+    setattr(to_model, "__pydantic_decorators__", prev_decorators)
+
+
+def replace_models_with_copy(
+    annotation: Type, source_model_field: Optional[str] = None
+) -> Any:
+    """
+    Replaces all models in annotation with their copies to avoid circular references.
+
+    :param annotation: annotation to replace models in
+    :type annotation: Type
+    :return: annotation with replaced models
+    :rtype: Type
+    """
+    if inspect.isclass(annotation) and issubclass(annotation, ormar.Model):
+        return create_copy_to_avoid_circular_references(model=annotation)
+    elif hasattr(annotation, "__origin__") and annotation.__origin__ in {list, Union}:
+        if annotation.__origin__ is list:
+            return List[  # type: ignore
+                replace_models_with_copy(
+                    annotation=annotation.__args__[0],
+                    source_model_field=source_model_field,
+                )
+            ]
+        elif annotation.__origin__ == Union:
+            args = annotation.__args__
+            new_args = [
+                replace_models_with_copy(
+                    annotation=arg, source_model_field=source_model_field
+                )
+                for arg in args
+            ]
+            return Union[tuple(new_args)]
+    else:
+        return annotation
+
+
+def create_copy_to_avoid_circular_references(model: Type["Model"]) -> Type["BaseModel"]:
+    new_model = create_model(
+        model.__name__,
+        __base__=model,
+    )
+    return new_model
+
+
 def register_through_shortcut_fields(model_field: "ManyToManyField") -> None:
     """
     Registers m2m relation through shortcut on both ends of the relation.
@@ -147,7 +257,7 @@ def register_through_shortcut_fields(model_field: "ManyToManyField") -> None:
     through_name = through_model.get_name(lower=True)
     related_name = model_field.get_related_name()
 
-    model_field.owner.Meta.model_fields[through_name] = Through(
+    model_field.owner.ormar_config.model_fields[through_name] = Through(
         through_model,
         real_name=through_name,
         virtual=True,
@@ -156,7 +266,7 @@ def register_through_shortcut_fields(model_field: "ManyToManyField") -> None:
         nullable=True,
     )
 
-    model_field.to.Meta.model_fields[through_name] = Through(
+    model_field.to.ormar_config.model_fields[through_name] = Through(
         through_model,
         real_name=through_name,
         virtual=True,
@@ -209,10 +319,13 @@ def verify_related_name_dont_duplicate(
     :return: None
     :rtype: None
     """
-    fk_field = model_field.to.Meta.model_fields.get(related_name)
+    fk_field = model_field.to.ormar_config.model_fields.get(related_name)
     if not fk_field:  # pragma: no cover
         return
-    if fk_field.to != model_field.owner and fk_field.to.Meta != model_field.owner.Meta:
+    if (
+        fk_field.to != model_field.owner
+        and fk_field.to.ormar_config != model_field.owner.ormar_config
+    ):
         raise ormar.ModelDefinitionError(
             f"Relation with related_name "
             f"'{related_name}' "
@@ -237,8 +350,10 @@ def reverse_field_not_already_registered(model_field: "ForeignKeyField") -> bool
     :rtype: bool
     """
     related_name = model_field.get_related_name()
-    check_result = related_name not in model_field.to.Meta.model_fields
-    check_result2 = model_field.owner.get_name() not in model_field.to.Meta.model_fields
+    check_result = related_name not in model_field.to.ormar_config.model_fields
+    check_result2 = (
+        model_field.owner.get_name() not in model_field.to.ormar_config.model_fields
+    )
 
     if not check_result:
         verify_related_name_dont_duplicate(
