@@ -2,16 +2,16 @@ import base64
 import sys
 import warnings
 from typing import (
+    TYPE_CHECKING,
     AbstractSet,
     Any,
-    Callable,
     Dict,
     List,
+    Literal,
     Mapping,
     MutableSequence,
     Optional,
     Set,
-    TYPE_CHECKING,
     Tuple,
     Type,
     TypeVar,
@@ -19,33 +19,31 @@ from typing import (
     cast,
 )
 
-import databases
 import pydantic
 import sqlalchemy
-from pydantic import BaseModel
-
+import typing_extensions
 
 import ormar  # noqa I100
 from ormar.exceptions import ModelError, ModelPersistenceError
-from ormar.fields import BaseField
 from ormar.fields.foreign_key import ForeignKeyField
-from ormar.fields.parsers import encode_json
+from ormar.fields.parsers import decode_bytes, encode_json
 from ormar.models.helpers import register_relation_in_alias_manager
 from ormar.models.helpers.relations import expand_reverse_relationship
 from ormar.models.helpers.sqlalchemy import (
-    populate_meta_sqlalchemy_table_if_required,
+    populate_config_sqlalchemy_table_if_required,
     update_column_definition,
 )
-from ormar.models.metaclass import ModelMeta, ModelMetaclass
+from ormar.models.metaclass import ModelMetaclass
 from ormar.models.modelproxy import ModelTableProxy
 from ormar.models.utils import Extra
 from ormar.queryset.utils import translate_list_to_dict
 from ormar.relations.alias_manager import AliasManager
 from ormar.relations.relation import Relation
 from ormar.relations.relation_manager import RelationsManager
+from ormar.warnings import OrmarDeprecatedSince020
 
 if TYPE_CHECKING:  # pragma no cover
-    from ormar.models import Model
+    from ormar.models import Model, OrmarConfig
     from ormar.signals import SignalEmitter
 
     T = TypeVar("T", bound="NewBaseModel")
@@ -64,7 +62,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
     Constructed with ModelMetaclass which in turn also inherits pydantic metaclass.
 
     Abstracts away all internals and helper functions, so final Model class has only
-    the logic concerned with database connection and data persistance.
+    the logic concerned with database connection and data persistence.
     """
 
     __slots__ = (
@@ -74,17 +72,12 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         "_pk_column",
         "__pk_only__",
         "__cached_hash__",
+        "__pydantic_extra__",
+        "__pydantic_fields_set__",
     )
 
     if TYPE_CHECKING:  # pragma no cover
         pk: Any
-        __model_fields__: Dict[str, BaseField]
-        __table__: sqlalchemy.Table
-        __pydantic_model__: Type[BaseModel]
-        __pkname__: str
-        __tablename__: str
-        __metadata__: sqlalchemy.MetaData
-        __database__: databases.Database
         __relation_map__: Optional[List[str]]
         __cached_hash__: Optional[int]
         _orm_relationship_manager: AliasManager
@@ -94,12 +87,10 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         _related_names: Optional[Set]
         _through_names: Optional[Set]
         _related_names_hash: str
-        _choices_fields: Set
-        _pydantic_fields: Set
         _quick_access_fields: Set
         _json_fields: Set
         _bytes_fields: Set
-        Meta: ModelMeta
+        ormar_config: OrmarConfig
 
     # noinspection PyMissingConstructor
     def __init__(self, *args: Any, **kwargs: Any) -> None:  # type: ignore
@@ -117,7 +108,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
         Json fields are automatically loaded/dumped if needed.
 
-        Models marked as abstract=True in internal Meta class cannot be initialized.
+        Models marked as abstract=True in internal OrmarConfig cannot be initialized.
 
         Accepts also special __pk_only__ flag that indicates that Model is constructed
         only with primary key value (so no other fields, it's a child model on other
@@ -144,31 +135,23 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         new_kwargs, through_tmp_dict = self._process_kwargs(kwargs)
 
         if not pk_only:
-            values, fields_set, validation_error = pydantic.validate_model(
-                self, new_kwargs  # type: ignore
+            self.__pydantic_validator__.validate_python(
+                new_kwargs, self_instance=self  # type: ignore
             )
-            if validation_error:
-                raise validation_error
         else:
-            fields_set = {self.Meta.pkname}
+            fields_set = {self.ormar_config.pkname}
             values = new_kwargs
-
-        object.__setattr__(self, "__dict__", values)
-        object.__setattr__(self, "__fields_set__", fields_set)
-
+            object.__setattr__(self, "__dict__", values)
+            object.__setattr__(self, "__pydantic_fields_set__", fields_set)
         # add back through fields
         new_kwargs.update(through_tmp_dict)
-        model_fields = object.__getattribute__(self, "Meta").model_fields
+        model_fields = object.__getattribute__(self, "ormar_config").model_fields
         # register the columns models after initialization
         for related in self.extract_related_names().union(self.extract_through_names()):
             model_fields[related].expand_relationship(
                 new_kwargs.get(related), self, to_register=True
             )
 
-        if hasattr(self, "_init_private_attributes"):
-            # introduced in pydantic 1.7
-            self._init_private_attributes()
-
     def __setattr__(self, name: str, value: Any) -> None:  # noqa CCR001
         """
         Overwrites setattr in pydantic parent as otherwise descriptors are not called.
@@ -189,7 +172,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             super().__setattr__(name, value)
 
         # In this case, the hash could have changed, so update it
-        if name == self.Meta.pkname or self.pk is None:
+        if name == self.ormar_config.pkname or self.pk is None:
             object.__setattr__(self, "__cached_hash__", None)
             new_hash = hash(self)
 
@@ -198,20 +181,21 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
     def __getattr__(self, item: str) -> Any:
         """
-        Used only to silence mypy errors for Through models and reverse relations.
-        Not used in real life as in practice calls are intercepted
-        by RelationDescriptors
+        Used for private attributes of pydantic v2.
 
         :param item: name of attribute
         :type item: str
         :return: Any
         :rtype: Any
         """
-        return super().__getattribute__(item)
+        # TODO: Check __pydantic_extra__
+        if item == "__pydantic_extra__":
+            return None
+        return super().__getattr__(item)  # type: ignore
 
     def __getstate__(self) -> Dict[Any, Any]:
         state = super().__getstate__()
-        self_dict = self.dict()
+        self_dict = self.model_dump()
         state["__dict__"].update(**self_dict)
         return state
 
@@ -274,9 +258,9 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :return: None
         :rtype: None
         """
-        if self.Meta.abstract:
+        if self.ormar_config.abstract:
             raise ModelError(f"You cannot initialize abstract model {self.get_name()}")
-        if self.Meta.requires_ref_update:
+        if self.ormar_config.requires_ref_update:
             raise ModelError(
                 f"Model {self.get_name()} has not updated "
                 f"ForwardRefs. \nBefore using the model you "
@@ -289,7 +273,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
         Removes property_fields
 
-        Checks if field is in the model fields or pydatnic fields.
+        Checks if field is in the model fields or pydantic fields.
 
         Nullifies fields that should be excluded.
 
@@ -300,9 +284,9 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :return: modified kwargs
         :rtype: Tuple[Dict, Dict]
         """
-        property_fields = self.Meta.property_fields
-        model_fields = self.Meta.model_fields
-        pydantic_fields = set(self.__fields__.keys())
+        property_fields = self.ormar_config.property_fields
+        model_fields = self.ormar_config.model_fields
+        pydantic_fields = set(self.model_fields.keys())
 
         # remove property fields
         for prop_filed in property_fields:
@@ -310,7 +294,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
         excluded: Set[str] = kwargs.pop("__excluded__", set())
         if "pk" in kwargs:
-            kwargs[self.Meta.pkname] = kwargs.pop("pk")
+            kwargs[self.ormar_config.pkname] = kwargs.pop("pk")
 
         # extract through fields
         through_tmp_dict = dict()
@@ -326,9 +310,13 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                     k,
                     self._convert_json(
                         k,
-                        model_fields[k].expand_relationship(v, self, to_register=False)
-                        if k in model_fields
-                        else (v if k in pydantic_fields else model_fields[k]),
+                        (
+                            model_fields[k].expand_relationship(
+                                v, self, to_register=False
+                            )
+                            if k in model_fields
+                            else (v if k in pydantic_fields else model_fields[k])
+                        ),
                     ),
                 )
                 for k, v in kwargs.items()
@@ -360,7 +348,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :return: dict without extra fields
         :rtype: Dict
         """
-        if self.Meta.extra == Extra.ignore:
+        if self.ormar_config.extra == Extra.ignore:
             kwargs = {
                 k: v
                 for k, v in kwargs.items()
@@ -432,22 +420,6 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         else:
             return hash(self) == other.__hash__()
 
-    def _copy_and_set_values(
-        self: "NewBaseModel", values: "DictStrAny", fields_set: "SetStr", *, deep: bool
-    ) -> "NewBaseModel":
-        """
-        Overwrite related models values with dict representation to avoid infinite
-        recursion through related fields.
-        """
-        self_dict = values
-        self_dict.update(self.dict(exclude_list=True))
-        return cast(
-            "NewBaseModel",
-            super()._copy_and_set_values(
-                values=self_dict, fields_set=fields_set, deep=deep
-            ),
-        )
-
     @classmethod
     def get_name(cls, lower: bool = True) -> str:
         """
@@ -466,7 +438,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
     @property
     def pk_column(self) -> sqlalchemy.Column:
         """
-        Retrieves primary key sqlalchemy column from models Meta.table.
+        Retrieves primary key sqlalchemy column from models OrmarConfig.table.
         Each model has to have primary key.
         Only one primary key column is allowed.
 
@@ -475,7 +447,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """
         if object.__getattribute__(self, "_pk_column") is not None:
             return object.__getattribute__(self, "_pk_column")
-        pk_columns = self.Meta.table.primary_key.columns.values()
+        pk_columns = self.ormar_config.table.primary_key.columns.values()
         pk_col = pk_columns[0]
         object.__setattr__(self, "_pk_column", pk_col)
         return pk_col
@@ -487,19 +459,19 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
     @property
     def signals(self) -> "SignalEmitter":
-        """Exposes signals from model Meta"""
-        return self.Meta.signals
+        """Exposes signals from model OrmarConfig"""
+        return self.ormar_config.signals
 
     @classmethod
     def pk_type(cls) -> Any:
         """Shortcut to models primary key field type"""
-        return cls.Meta.model_fields[cls.Meta.pkname].__type__
+        return cls.ormar_config.model_fields[cls.ormar_config.pkname].__type__
 
     @classmethod
     def db_backend_name(cls) -> str:
         """Shortcut to database dialect,
         cause some dialect require different treatment"""
-        return cls.Meta.database._backend._dialect.name
+        return cls.ormar_config.database._backend._dialect.name
 
     def remove(self, parent: "Model", name: str) -> None:
         """Removes child from relation with given name in RelationshipManager"""
@@ -509,32 +481,6 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """Sets value of the save status"""
         object.__setattr__(self, "_orm_saved", status)
 
-    @classmethod
-    def get_properties(
-        cls, include: Union[Set, Dict, None], exclude: Union[Set, Dict, None]
-    ) -> Set[str]:
-        """
-        Returns a set of names of functions/fields decorated with
-        @property_field decorator.
-
-        They are added to dictionary when called directly and therefore also are
-        present in fastapi responses.
-
-        :param include: fields to include
-        :type include: Union[Set, Dict, None]
-        :param exclude: fields to exclude
-        :type exclude: Union[Set, Dict, None]
-        :return: set of property fields names
-        :rtype: Set[str]
-        """
-
-        props = cls.Meta.property_fields
-        if include:
-            props = {prop for prop in props if prop in include}
-        if exclude:
-            props = {prop for prop in props if prop not in exclude}
-        return props
-
     @classmethod
     def update_forward_refs(cls, **localns: Any) -> None:
         """
@@ -544,7 +490,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         Expands relationships, register relation in alias manager and substitutes
         sqlalchemy columns with new ones with proper column type (null before).
 
-        Populates Meta table of the Model which is left empty before.
+        Populates OrmarConfig table of the Model which is left empty before.
 
         Sets self_reference flag on models that links to themselves.
 
@@ -557,7 +503,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """
         globalns = sys.modules[cls.__module__].__dict__.copy()
         globalns.setdefault(cls.__name__, cls)
-        fields_to_check = cls.Meta.model_fields.copy()
+        fields_to_check = cls.ormar_config.model_fields.copy()
         for field in fields_to_check.values():
             if field.has_unresolved_forward_refs():
                 field = cast(ForeignKeyField, field)
@@ -569,9 +515,10 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                 expand_reverse_relationship(model_field=field)
                 register_relation_in_alias_manager(field=field)
                 update_column_definition(model=cls, field=field)
-        populate_meta_sqlalchemy_table_if_required(meta=cls.Meta)
-        super().update_forward_refs(**localns)
-        cls.Meta.requires_ref_update = False
+        populate_config_sqlalchemy_table_if_required(config=cls.ormar_config)
+        # super().update_forward_refs(**localns)
+        cls.model_rebuild(force=True)
+        cls.ormar_config.requires_ref_update = False
 
     @staticmethod
     def _get_not_excluded_fields(
@@ -626,26 +573,84 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         result = []
         for model in models:
             try:
-                result.append(
-                    model.dict(
-                        relation_map=relation_map,
+                model_dict = model.model_dump(
+                    relation_map=relation_map,
+                    include=include,
+                    exclude=exclude,
+                    exclude_primary_keys=exclude_primary_keys,
+                    exclude_through_models=exclude_through_models,
+                )
+                if not exclude_through_models:
+                    model.populate_through_models(
+                        model=model,
+                        model_dict=model_dict,
                         include=include,
                         exclude=exclude,
-                        exclude_primary_keys=exclude_primary_keys,
-                        exclude_through_models=exclude_through_models,
+                        relation_map=relation_map,
                     )
-                )
+                result.append(model_dict)
             except ReferenceError:  # pragma no cover
                 continue
         return result
 
+    @staticmethod
+    def populate_through_models(
+        model: "Model",
+        model_dict: Dict,
+        include: Union[Set, Dict],
+        exclude: Union[Set, Dict],
+        relation_map: Dict,
+    ) -> None:
+        """
+        Populates through models with values from dict representation.
+
+        :param model: model to populate through models
+        :type model: Model
+        :param model_dict: dict representation of the model
+        :type model_dict: Dict
+        :param include: fields to include
+        :type include: Dict
+        :param exclude: fields to exclude
+        :type exclude: Dict
+        :param relation_map: map of relations to follow to avoid circular refs
+        :type relation_map: Dict
+        :return: None
+        :rtype: None
+        """
+
+        include_dict = (
+            translate_list_to_dict(include)
+            if (include and isinstance(include, Set))
+            else include
+        )
+        exclude_dict = (
+            translate_list_to_dict(exclude)
+            if (exclude and isinstance(exclude, Set))
+            else exclude
+        )
+        models_to_populate = model._get_not_excluded_fields(
+            fields=model.extract_through_names(),
+            include=cast(Optional[Dict], include_dict),
+            exclude=cast(Optional[Dict], exclude_dict),
+        )
+        through_fields_to_populate = [
+            model.ormar_config.model_fields[through_model]
+            for through_model in models_to_populate
+            if model.ormar_config.model_fields[through_model].related_name
+            not in relation_map
+        ]
+        for through_field in through_fields_to_populate:
+            through_instance = getattr(model, through_field.name)
+            if through_instance:
+                model_dict[through_field.name] = through_instance.model_dump()
+
     @classmethod
     def _skip_ellipsis(
         cls, items: Union[Set, Dict, None], key: str, default_return: Any = None
     ) -> Union[Set, Dict, None]:
         """
         Helper to traverse the include/exclude dictionaries.
-        In dict() Ellipsis should be skipped as it indicates all fields required
+        In model_dump() Ellipsis should be skipped as it indicates all fields required
         and not the actual set/dict with fields names.
 
         :param items: current include/exclude value
@@ -722,8 +727,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                         exclude_through_models=exclude_through_models,
                     )
                 elif nested_model is not None:
-
-                    dict_instance[field] = nested_model.dict(
+                    model_dict = nested_model.model_dump(
                         relation_map=self._skip_ellipsis(
                             relation_map, field, default_return=dict()
                         ),
@@ -732,26 +736,78 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                         exclude_primary_keys=exclude_primary_keys,
                         exclude_through_models=exclude_through_models,
                     )
+                    if not exclude_through_models:
+                        nested_model.populate_through_models(
+                            model=nested_model,
+                            model_dict=model_dict,
+                            include=self._convert_all(
+                                self._skip_ellipsis(include, field)
+                            ),
+                            exclude=self._convert_all(
+                                self._skip_ellipsis(exclude, field)
+                            ),
+                            relation_map=self._skip_ellipsis(
+                                relation_map, field, default_return=dict()
+                            ),
+                        )
+                    dict_instance[field] = model_dict
                 else:
                     dict_instance[field] = None
-            except ReferenceError:
+            except ReferenceError:  # pragma: no cover
                 dict_instance[field] = None
         return dict_instance
 
+    @typing_extensions.deprecated(
+        "The `dict` method is deprecated; use `model_dump` instead.",
+        category=OrmarDeprecatedSince020,
+    )
     def dict(  # type: ignore # noqa A003
         self,
         *,
-        include: Union[Set, Dict] = None,
-        exclude: Union[Set, Dict] = None,
+        include: Union[Set, Dict, None] = None,
+        exclude: Union[Set, Dict, None] = None,
         by_alias: bool = False,
-        skip_defaults: bool = None,
         exclude_unset: bool = False,
         exclude_defaults: bool = False,
         exclude_none: bool = False,
         exclude_primary_keys: bool = False,
         exclude_through_models: bool = False,
         exclude_list: bool = False,
-        relation_map: Dict = None,
+        relation_map: Optional[Dict] = None,
+    ) -> "DictStrAny":  # noqa: A003 # pragma: no cover
+        warnings.warn(
+            "The `dict` method is deprecated; use `model_dump` instead.",
+            DeprecationWarning,
+        )
+        return self.model_dump(
+            include=include,
+            exclude=exclude,
+            by_alias=by_alias,
+            exclude_unset=exclude_unset,
+            exclude_defaults=exclude_defaults,
+            exclude_none=exclude_none,
+            exclude_primary_keys=exclude_primary_keys,
+            exclude_through_models=exclude_through_models,
+            exclude_list=exclude_list,
+            relation_map=relation_map,
+        )
+
+    def model_dump(  # type: ignore # noqa A003
+        self,
+        *,
+        mode: Union[Literal["json", "python"], str] = "python",
+        include: Union[Set, Dict, None] = None,
+        exclude: Union[Set, Dict, None] = None,
+        by_alias: bool = False,
+        exclude_unset: bool = False,
+        exclude_defaults: bool = False,
+        exclude_none: bool = False,
+        exclude_primary_keys: bool = False,
+        exclude_through_models: bool = False,
+        exclude_list: bool = False,
+        relation_map: Optional[Dict] = None,
+        round_trip: bool = False,
+        warnings: bool = True,
     ) -> "DictStrAny":  # noqa: A003'
         """
 
@@ -760,7 +816,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
 
         Nested models are also parsed to dictionaries.
 
-        Additionally fields decorated with @property_field are also added.
+        Additionally, fields decorated with @property_field are also added.
 
         :param exclude_through_models: flag to exclude through models from dict
         :type exclude_through_models: bool
@@ -772,8 +828,6 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :type exclude: Union[Set, Dict, None]
         :param by_alias: flag to get values by alias - passed to pydantic
         :type by_alias: bool
-        :param skip_defaults: flag to not set values - passed to pydantic
-        :type skip_defaults: bool
         :param exclude_unset: flag to exclude not set values - passed to pydantic
         :type exclude_unset: bool
         :param exclude_defaults: flag to exclude default values - passed to pydantic
@@ -782,8 +836,16 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :type exclude_none: bool
         :param exclude_list: flag to exclude lists of nested values models from dict
         :type exclude_list: bool
-        :param relation_map: map of the relations to follow to avoid circural deps
+        :param relation_map: map of the relations to follow to avoid circular deps
         :type relation_map: Dict
+        :param mode: The mode in which `to_python` should run.
+            If mode is 'json', the dictionary will only contain JSON serializable types.
+            If mode is 'python', the dictionary may contain any Python objects.
+        :type mode: str
+        :param round_trip: flag to enable serialization round-trip support
+        :type round_trip: bool
+        :param warnings: flag to log warnings for invalid fields
+        :type warnings: bool
         :return:
         :rtype:
         """
@@ -793,14 +855,16 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             exclude_primary_keys=exclude_primary_keys,
             exclude_through_models=exclude_through_models,
         )
-        dict_instance = super().dict(
+        dict_instance = super().model_dump(
+            mode=mode,
             include=include,
             exclude=pydantic_exclude,
             by_alias=by_alias,
-            skip_defaults=skip_defaults,
-            exclude_unset=exclude_unset,
             exclude_defaults=exclude_defaults,
+            exclude_unset=exclude_unset,
             exclude_none=exclude_none,
+            round_trip=round_trip,
+            warnings=False,
         )
 
         dict_instance = {
@@ -808,10 +872,12 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             for k, v in dict_instance.items()
         }
 
-        if include and isinstance(include, Set):
-            include = translate_list_to_dict(include)
-        if exclude and isinstance(exclude, Set):
-            exclude = translate_list_to_dict(exclude)
+        include_dict = (
+            translate_list_to_dict(include) if isinstance(include, Set) else include
+        )
+        exclude_dict = (
+            translate_list_to_dict(exclude) if isinstance(exclude, Set) else exclude
+        )
 
         relation_map = (
             relation_map
@@ -823,32 +889,57 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             dict_instance = self._extract_nested_models(
                 relation_map=relation_map,
                 dict_instance=dict_instance,
-                include=include,  # type: ignore
-                exclude=exclude,  # type: ignore
+                include=include_dict,
+                exclude=exclude_dict,
                 exclude_primary_keys=exclude_primary_keys,
                 exclude_through_models=exclude_through_models,
                 exclude_list=exclude_list,
             )
 
-        # include model properties as fields in dict
-        if object.__getattribute__(self, "Meta").property_fields:
-            props = self.get_properties(include=include, exclude=exclude)
-            if props:
-                dict_instance.update({prop: getattr(self, prop) for prop in props})
-
         return dict_instance
 
+    @typing_extensions.deprecated(
+        "The `json` method is deprecated; use `model_dump_json` instead.",
+        category=OrmarDeprecatedSince020,
+    )
     def json(  # type: ignore # noqa A003
         self,
         *,
-        include: Union[Set, Dict] = None,
-        exclude: Union[Set, Dict] = None,
+        include: Union[Set, Dict, None] = None,
+        exclude: Union[Set, Dict, None] = None,
+        by_alias: bool = False,
+        exclude_unset: bool = False,
+        exclude_defaults: bool = False,
+        exclude_none: bool = False,
+        exclude_primary_keys: bool = False,
+        exclude_through_models: bool = False,
+        **dumps_kwargs: Any,
+    ) -> str:  # pragma: no cover
+        warnings.warn(
+            "The `json` method is deprecated; use `model_dump_json` instead.",
+            DeprecationWarning,
+        )
+        return self.model_dump_json(
+            include=include,
+            exclude=exclude,
+            by_alias=by_alias,
+            exclude_unset=exclude_unset,
+            exclude_defaults=exclude_defaults,
+            exclude_none=exclude_none,
+            exclude_primary_keys=exclude_primary_keys,
+            exclude_through_models=exclude_through_models,
+            **dumps_kwargs,
+        )
+
+    def model_dump_json(  # type: ignore # noqa A003
+        self,
+        *,
+        include: Union[Set, Dict, None] = None,
+        exclude: Union[Set, Dict, None] = None,
         by_alias: bool = False,
-        skip_defaults: bool = None,
         exclude_unset: bool = False,
         exclude_defaults: bool = False,
         exclude_none: bool = False,
-        encoder: Optional[Callable[[Any], Any]] = None,
         exclude_primary_keys: bool = False,
         exclude_through_models: bool = False,
         **dumps_kwargs: Any,
@@ -860,15 +951,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         `encoder` is an optional function to supply as `default` to json.dumps(),
         other arguments as per `json.dumps()`.
         """
-        if skip_defaults is not None:  # pragma: no cover
-            warnings.warn(
-                f'{self.__class__.__name__}.json(): "skip_defaults" is deprecated '
-                f'and replaced by "exclude_unset"',
-                DeprecationWarning,
-            )
-            exclude_unset = skip_defaults
-        encoder = cast(Callable[[Any], Any], encoder or self.__json_encoder__)
-        data = self.dict(
+        data = self.model_dump(
             include=include,
             exclude=exclude,
             by_alias=by_alias,
@@ -878,12 +961,24 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             exclude_primary_keys=exclude_primary_keys,
             exclude_through_models=exclude_through_models,
         )
-        if self.__custom_root_type__:  # pragma: no cover
-            data = data["__root__"]
-        return self.__config__.json_dumps(data, default=encoder, **dumps_kwargs)
+        return self.__pydantic_serializer__.to_json(data, warnings=False).decode()
 
     @classmethod
+    @typing_extensions.deprecated(
+        "The `construct` method is deprecated; use `model_construct` instead.",
+        category=OrmarDeprecatedSince020,
+    )
     def construct(
+        cls: Type["T"], _fields_set: Union[Set[str], None] = None, **values: Any
+    ) -> "T":  # pragma: no cover
+        warnings.warn(
+            "The `construct` method is deprecated; use `model_construct` instead.",
+            DeprecationWarning,
+        )
+        return cls.model_construct(_fields_set=_fields_set, **values)
+
+    @classmethod
+    def model_construct(
         cls: Type["T"], _fields_set: Optional["SetStr"] = None, **values: Any
     ) -> "T":
         own_values = {
@@ -891,18 +986,52 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         }
         model = cls.__new__(cls)
         fields_values: Dict[str, Any] = {}
-        for name, field in cls.__fields__.items():
+        for name, field in cls.model_fields.items():
             if name in own_values:
                 fields_values[name] = own_values[name]
-            elif not field.required:
+            elif not field.is_required():
                 fields_values[name] = field.get_default()
         fields_values.update(own_values)
+
+        if _fields_set is None:
+            _fields_set = set(values.keys())
+
+        extra_allowed = cls.model_config.get("extra") == "allow"
+        if not extra_allowed:
+            fields_values.update(values)
         object.__setattr__(model, "__dict__", fields_values)
         model._initialize_internal_attributes()
         cls._construct_relations(model=model, values=values)
-        if _fields_set is None:
-            _fields_set = set(values.keys())
-        object.__setattr__(model, "__fields_set__", _fields_set)
+        object.__setattr__(model, "__pydantic_fields_set__", _fields_set)
+        return cls._pydantic_model_construct_finalizer(
+            model=model, extra_allowed=extra_allowed, values=values
+        )
+
+    @classmethod
+    def _pydantic_model_construct_finalizer(
+        cls: Type["T"], model: "T", extra_allowed: bool, **values: Any
+    ) -> "T":
+        """
+        Recreate pydantic model_construct logic here as we do not call super method.
+        """
+        _extra: Union[Dict[str, Any], None] = None
+        if extra_allowed:  # pragma: no cover
+            _extra = {}
+            for k, v in values.items():
+                _extra[k] = v
+
+        if not cls.__pydantic_root_model__:
+            object.__setattr__(model, "__pydantic_extra__", _extra)
+
+        if cls.__pydantic_post_init__:  # pragma: no cover
+            model.model_post_init(None)
+        elif not cls.__pydantic_root_model__:
+            # Note: if there are any private attributes,
+            # cls.__pydantic_post_init__ would exist
+            # Since it doesn't, that means that `__pydantic_private__`
+            # should be set to None
+            object.__setattr__(model, "__pydantic_private__", None)
+
         return model
 
     @classmethod
@@ -914,7 +1043,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             value_to_set = values[relation]
             if not isinstance(value_to_set, list):
                 value_to_set = [value_to_set]
-            relation_field = cls.Meta.model_fields[relation]
+            relation_field = cls.ormar_config.model_fields[relation]
             relation_value = [
                 relation_field.expand_relationship(x, model, to_register=False)
                 for x in value_to_set
@@ -954,12 +1083,11 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """
         if column_name not in self._bytes_fields:
             return value
-        field = self.Meta.model_fields[column_name]
-        if not isinstance(value, bytes) and value is not None:
-            if field.represent_as_base64_str:
-                value = base64.b64decode(value)
-            else:
-                value = value.encode("utf-8")
+        field = self.ormar_config.model_fields[column_name]
+        if value is not None:
+            value = decode_bytes(
+                value=value, represent_as_string=field.represent_as_base64_str
+            )
         return value
 
     def _convert_bytes_to_str(self, column_name: str, value: Any) -> Union[str, Dict]:
@@ -975,7 +1103,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """
         if column_name not in self._bytes_fields:
             return value
-        field = self.Meta.model_fields[column_name]
+        field = self.ormar_config.model_fields[column_name]
         if (
             value is not None
             and not isinstance(value, str)
@@ -1021,16 +1149,15 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         :return: dictionary of fields names and values.
         :rtype: Dict
         """
-        # TODO: Cache this dictionary?
         self_fields = self._extract_own_model_fields()
         self_fields = {
             k: v
             for k, v in self_fields.items()
-            if self.get_column_alias(k) in self.Meta.table.columns
+            if self.get_column_alias(k) in self.ormar_config.table.columns
         }
         for field in self._extract_db_related_names():
-            relation_field = self.Meta.model_fields[field]
-            target_pk_name = relation_field.to.Meta.pkname
+            relation_field = self.ormar_config.model_fields[field]
+            target_pk_name = relation_field.to.ormar_config.pkname
             target_field = getattr(self, field)
             self_fields[field] = getattr(target_field, target_pk_name, None)
             if not relation_field.nullable and not self_fields[field]:
@@ -1039,18 +1166,3 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                     f"model without pk set!"
                 )
         return self_fields
-
-    def get_relation_model_id(self, target_field: "BaseField") -> Optional[int]:
-        """
-        Returns an id of the relation side model to use in prefetch query.
-
-        :param target_field: field with relation definition
-        :type target_field: "BaseField"
-        :return: value of pk if set
-        :rtype: Optional[int]
-        """
-        if target_field.virtual or target_field.is_multi:
-            return self.pk
-        related_name = target_field.name
-        related_model = getattr(self, related_name)
-        return None if not related_model else related_model.pk
