@@ -10,8 +10,6 @@ if TYPE_CHECKING:  # pragma: nocover
 
 
 class RelationProtocol(Protocol):  # pragma: nocover
-    def add(self, child: "Model") -> None:
-        ...
+    def add(self, child: "Model") -> None: ...
 
-    def remove(self, child: Union["Model", Type["Model"]]) -> None:
-        ...
+    def remove(self, child: Union["Model", Type["Model"]]) -> None: ...
