@@ -1,13 +1,11 @@
 """
 Contains QuerySet and different Query classes to allow for constructing of sql queries.
 """
+
 from ormar.queryset.actions import FilterAction, OrderAction, SelectAction
 from ormar.queryset.clause import and_, or_
 from ormar.queryset.field_accessor import FieldAccessor
-from ormar.queryset.queries import FilterQuery
-from ormar.queryset.queries import LimitQuery
-from ormar.queryset.queries import OffsetQuery
-from ormar.queryset.queries import OrderQuery
+from ormar.queryset.queries import FilterQuery, LimitQuery, OffsetQuery, OrderQuery
 from ormar.queryset.queryset import QuerySet
 
 __all__ = [
