@@ -1,37 +1,28 @@
 from typing import Optional
 from uuid import UUID, uuid4
 
-import databases
+import ormar
 import pytest
-import sqlalchemy
 from asgi_lifespan import LifespanManager
 from fastapi import FastAPI
 from httpx import AsyncClient
 
-import ormar
+from tests.lifespan import init_tests, lifespan
+from tests.settings import create_config
 
-app = FastAPI()
-DATABASE_URL = "sqlite:///db.sqlite"
-database = databases.Database(DATABASE_URL)
-metadata = sqlalchemy.MetaData()
-
-
-class BaseMeta(ormar.ModelMeta):
-    metadata = metadata
-    database = database
+base_ormar_config = create_config()
+app = FastAPI(lifespan=lifespan(base_ormar_config))
 
 
 class CA(ormar.Model):
-    class Meta(BaseMeta):
-        tablename = "cas"
+    ormar_config = base_ormar_config.copy(tablename="cas")
 
     id: UUID = ormar.UUID(primary_key=True, default=uuid4)
     ca_name: str = ormar.Text(default="")
 
 
 class CB1(ormar.Model):
-    class Meta(BaseMeta):
-        tablename = "cb1s"
+    ormar_config = base_ormar_config.copy(tablename="cb1s")
 
     id: UUID = ormar.UUID(primary_key=True, default=uuid4)
     cb1_name: str = ormar.Text(default="")
@@ -39,14 +30,16 @@ class CB1(ormar.Model):
 
 
 class CB2(ormar.Model):
-    class Meta(BaseMeta):
-        tablename = "cb2s"
+    ormar_config = base_ormar_config.copy(tablename="cb2s")
 
     id: UUID = ormar.UUID(primary_key=True, default=uuid4)
     cb2_name: str = ormar.Text(default="")
     ca2: Optional[CA] = ormar.ForeignKey(CA, nullable=True)
 
 
+create_test_database = init_tests(base_ormar_config)
+
+
 @app.get("/ca", response_model=CA)
 async def get_ca():  # pragma: no cover
     return None
@@ -70,6 +63,7 @@ async def test_all_endpoints():
         assert response.status_code == 200, response.text
         schema = response.json()
         components = schema["components"]["schemas"]
-        assert all(x in components for x in ["CA", "CB1", "CB2"])
-        pk_onlys = [x for x in list(components.keys()) if x.startswith("PkOnly")]
-        assert len(pk_onlys) == 2
+        raw_names_w_o_modules = [x.split("__")[-1] for x in components.keys()]
+        assert all(x in raw_names_w_o_modules for x in ["CA", "CB1", "CB2"])
+        pk_onlys = [x for x in list(raw_names_w_o_modules) if x.startswith("PkOnly")]
+        assert len(pk_onlys) == 4
