@@ -1,52 +1,29 @@
-import json
 from typing import Any, Dict, Optional, Set, Type, Union, cast
 
-import databases
+import ormar
 import pytest
-import sqlalchemy
 from asgi_lifespan import LifespanManager
 from fastapi import FastAPI
 from httpx import AsyncClient
-
-import ormar
 from ormar.queryset.utils import translate_list_to_dict
-from tests.settings import DATABASE_URL
 
-app = FastAPI()
-metadata = sqlalchemy.MetaData()
-database = databases.Database(DATABASE_URL, force_rollback=True)
-app.state.database = database
+from tests.lifespan import init_tests, lifespan
+from tests.settings import create_config
 
+base_ormar_config = create_config()
+app = FastAPI(lifespan=lifespan(base_ormar_config))
 headers = {"content-type": "application/json"}
 
 
-@app.on_event("startup")
-async def startup() -> None:
-    database_ = app.state.database
-    if not database_.is_connected:
-        await database_.connect()
-
-
-@app.on_event("shutdown")
-async def shutdown() -> None:
-    database_ = app.state.database
-    if database_.is_connected:
-        await database_.disconnect()
-
-
 class Department(ormar.Model):
-    class Meta:
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True)
     department_name: str = ormar.String(max_length=100)
 
 
 class Course(ormar.Model):
-    class Meta:
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True)
     course_name: str = ormar.String(max_length=100)
@@ -55,24 +32,13 @@ class Course(ormar.Model):
 
 
 class Student(ormar.Model):
-    class Meta:
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True)
     name: str = ormar.String(max_length=100)
     courses = ormar.ManyToMany(Course)
 
 
-# create db and tables
-@pytest.fixture(autouse=True, scope="module")
-def create_test_database():
-    engine = sqlalchemy.create_engine(DATABASE_URL)
-    metadata.create_all(engine)
-    yield
-    metadata.drop_all(engine)
-
-
 to_exclude = {
     "id": ...,
     "courses": {
@@ -88,6 +54,9 @@ to_exclude_ormar = {
 }
 
 
+create_test_database = init_tests(base_ormar_config)
+
+
 def auto_exclude_id_field(to_exclude: Any) -> Union[Dict, Set]:
     if isinstance(to_exclude, dict):
         for key in to_exclude.keys():
@@ -117,7 +86,7 @@ async def get_department(department_name: str):
     department = await Department.objects.select_all(follow=True).get(
         department_name=department_name
     )
-    return department.dict(exclude=to_exclude)
+    return department.model_dump(exclude=to_exclude)
 
 
 @app.get("/departments/{department_name}/second")
@@ -125,7 +94,7 @@ async def get_department_exclude(department_name: str):
     department = await Department.objects.select_all(follow=True).get(
         department_name=department_name
     )
-    return department.dict(exclude=to_exclude_ormar)
+    return department.model_dump(exclude=to_exclude_ormar)
 
 
 @app.get("/departments/{department_name}/exclude")
@@ -133,7 +102,7 @@ async def get_department_exclude_all(department_name: str):
     department = await Department.objects.select_all(follow=True).get(
         department_name=department_name
     )
-    return department.dict(exclude=exclude_all)
+    return department.model_dump(exclude=exclude_all)
 
 
 @pytest.mark.asyncio
