@@ -1,55 +1,22 @@
 from typing import List, Optional
 from uuid import UUID, uuid4
 
-import databases
+import ormar
 import pydantic
 import pytest
-import sqlalchemy
 from asgi_lifespan import LifespanManager
 from fastapi import FastAPI
 from httpx import AsyncClient
 
-import ormar
-from tests.settings import DATABASE_URL
+from tests.lifespan import init_tests, lifespan
+from tests.settings import create_config
 
-app = FastAPI()
-
-database = databases.Database(DATABASE_URL, force_rollback=True)
-metadata = sqlalchemy.MetaData()
-
-app.state.database = database
-
-
-@app.on_event("startup")
-async def startup() -> None:
-    database_ = app.state.database
-    if not database_.is_connected:
-        await database_.connect()
-
-
-@app.on_event("shutdown")
-async def shutdown() -> None:
-    database_ = app.state.database
-    if database_.is_connected:
-        await database_.disconnect()
-
-
-@pytest.fixture(autouse=True, scope="module")
-def create_test_database():
-    engine = sqlalchemy.create_engine(DATABASE_URL)
-    metadata.create_all(engine)
-    yield
-    metadata.drop_all(engine)
-
-
-class BaseMeta(ormar.ModelMeta):
-    database = database
-    metadata = metadata
+base_ormar_config = create_config()
+app = FastAPI(lifespan=lifespan(base_ormar_config))
 
 
 class OtherThing(ormar.Model):
-    class Meta(BaseMeta):
-        tablename = "other_things"
+    ormar_config = base_ormar_config.copy(tablename="other_things")
 
     id: UUID = ormar.UUID(primary_key=True, default=uuid4)
     name: str = ormar.Text(default="")
@@ -57,8 +24,7 @@ class OtherThing(ormar.Model):
 
 
 class Thing(ormar.Model):
-    class Meta(BaseMeta):
-        tablename = "things"
+    ormar_config = base_ormar_config.copy(tablename="things")
 
     id: UUID = ormar.UUID(primary_key=True, default=uuid4)
     name: str = ormar.Text(default="")
@@ -66,6 +32,9 @@ class Thing(ormar.Model):
     other_thing: Optional[OtherThing] = ormar.ForeignKey(OtherThing, nullable=True)
 
 
+create_test_database = init_tests(base_ormar_config)
+
+
 @app.post("/test/1")
 async def post_test_1():
     # don't split initialization and attribute assignment
@@ -98,7 +67,7 @@ async def get_test_3():
     ot = await OtherThing.objects.select_related("things").get()
     # exclude unwanted field while ot is still in scope
     # in order not to pass it to fastapi
-    return [t.dict(exclude={"other_thing"}) for t in ot.things]
+    return [t.model_dump(exclude={"other_thing"}) for t in ot.things]
 
 
 @app.get("/test/4", response_model=List[Thing], response_model_exclude={"other_thing"})
