@@ -1,39 +1,32 @@
-import databases
-import sqlalchemy
-
 import ormar
-from tests.settings import DATABASE_URL
 
-database = databases.Database(DATABASE_URL)
-metadata = sqlalchemy.MetaData()
+from tests.lifespan import init_tests
+from tests.settings import create_config
 
-
-class BaseMeta(ormar.ModelMeta):
-    metadata = metadata
-    database = database
+base_ormar_config = create_config()
 
 
 class AutoincrementModel(ormar.Model):
-    class Meta(BaseMeta):
-        pass
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True)
 
 
 class NonAutoincrementModel(ormar.Model):
-    class Meta(BaseMeta):
-        pass
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True, autoincrement=False)
 
 
 class ExplicitNullableModel(ormar.Model):
-    class Meta(BaseMeta):
-        pass
+    ormar_config = base_ormar_config.copy()
 
     id: int = ormar.Integer(primary_key=True, nullable=True)
 
 
+create_test_database = init_tests(base_ormar_config)
+
+
 def test_pk_field_is_not_null():
     for model in [AutoincrementModel, NonAutoincrementModel, ExplicitNullableModel]:
-        assert not model.Meta.table.c.get("id").nullable
+        assert not model.ormar_config.table.c.get("id").nullable
