@@ -2,24 +2,17 @@ import datetime
 import uuid
 from typing import Dict, Optional, Union
 
-import databases
-import pytest
-import sqlalchemy
-from sqlalchemy import create_engine
-
 import ormar
-from tests.settings import DATABASE_URL
+import pytest
 
-database = databases.Database(DATABASE_URL)
-metadata = sqlalchemy.MetaData()
-engine = create_engine(DATABASE_URL)
+from tests.lifespan import init_tests
+from tests.settings import create_config
+
+base_ormar_config = create_config()
 
 
 class Team(ormar.Model):
-    class Meta:
-        tablename: str = "team"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="team")
 
     id: uuid.UUID = ormar.UUID(default=uuid.uuid4, primary_key=True, index=True)
     name = ormar.Text(nullable=True)
@@ -29,10 +22,7 @@ class Team(ormar.Model):
 
 
 class User(ormar.Model):
-    class Meta:
-        tablename: str = "user"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="user")
 
     id: uuid.UUID = ormar.UUID(default=uuid.uuid4, primary_key=True, index=True)
     client_user_id = ormar.Text()
@@ -41,23 +31,16 @@ class User(ormar.Model):
 
 
 class Order(ormar.Model):
-    class Meta:
-        tablename: str = "order"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="order")
 
     id: uuid.UUID = ormar.UUID(default=uuid.uuid4, primary_key=True, index=True)
     user: Optional[Union[User, Dict]] = ormar.ForeignKey(User)
 
 
-@pytest.fixture(autouse=True, scope="module")
-def create_test_database():
-    metadata.create_all(engine)
-    yield
-    metadata.drop_all(engine)
+create_test_database = init_tests(base_ormar_config)
 
 
 @pytest.mark.asyncio
 async def test_quoting_on_clause_without_prefix():
-    async with database:
+    async with base_ormar_config.database:
         await User.objects.select_related("orders").all()
