@@ -1,24 +1,18 @@
-import asyncio
 from typing import List, Optional
 
-import databases
+import ormar
 import pytest
 import pytest_asyncio
-import sqlalchemy
-
-import ormar
 from ormar.exceptions import ModelPersistenceError, NoMatch, RelationshipInstanceError
-from tests.settings import DATABASE_URL
 
-database = databases.Database(DATABASE_URL, force_rollback=True)
-metadata = sqlalchemy.MetaData()
+from tests.lifespan import init_tests
+from tests.settings import create_config
+
+base_ormar_config = create_config(force_rollback=True)
 
 
 class Author(ormar.Model):
-    class Meta:
-        tablename = "authors"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="authors")
 
     id: int = ormar.Integer(primary_key=True)
     first_name: str = ormar.String(max_length=80)
@@ -26,20 +20,14 @@ class Author(ormar.Model):
 
 
 class Category(ormar.Model):
-    class Meta:
-        tablename = "categories"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="categories")
 
     id: int = ormar.Integer(primary_key=True)
     name: str = ormar.String(max_length=40)
 
 
 class Post(ormar.Model):
-    class Meta:
-        tablename = "posts"
-        database = database
-        metadata = metadata
+    ormar_config = base_ormar_config.copy(tablename="posts")
 
     id: int = ormar.Integer(primary_key=True)
     title: str = ormar.String(max_length=200)
@@ -47,26 +35,14 @@ class Post(ormar.Model):
     author: Optional[Author] = ormar.ForeignKey(Author)
 
 
-@pytest.fixture(scope="module")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
-    loop.close()
-
-
-@pytest_asyncio.fixture(autouse=True, scope="module")
-async def create_test_database():
-    engine = sqlalchemy.create_engine(DATABASE_URL)
-    metadata.create_all(engine)
-    yield
-    metadata.drop_all(engine)
+create_test_database = init_tests(base_ormar_config)
 
 
 @pytest_asyncio.fixture(scope="function")
 async def cleanup():
     yield
-    async with database:
-        PostCategory = Post.Meta.model_fields["categories"].through
+    async with base_ormar_config.database:
+        PostCategory = Post.ormar_config.model_fields["categories"].through
         await PostCategory.objects.delete(each=True)
         await Post.objects.delete(each=True)
         await Category.objects.delete(each=True)
@@ -75,7 +51,7 @@ async def cleanup():
 
 @pytest.mark.asyncio
 async def test_not_saved_raises_error(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author(first_name="Guido", last_name="Van Rossum").save()
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = Category(name="News")
@@ -86,7 +62,7 @@ async def test_not_saved_raises_error(cleanup):
 
 @pytest.mark.asyncio
 async def test_not_existing_raises_error(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author(first_name="Guido", last_name="Van Rossum").save()
         post = await Post.objects.create(title="Hello, M2M", author=guido)
 
@@ -98,7 +74,7 @@ async def test_not_existing_raises_error(cleanup):
 
 @pytest.mark.asyncio
 async def test_assigning_related_objects(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = await Category.objects.create(name="News")
@@ -121,7 +97,7 @@ async def test_assigning_related_objects(cleanup):
 
 @pytest.mark.asyncio
 async def test_quering_of_the_m2m_models(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         # orm can do this already.
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
@@ -156,7 +132,7 @@ async def test_quering_of_the_m2m_models(cleanup):
 
 @pytest.mark.asyncio
 async def test_removal_of_the_relations(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = await Category.objects.create(name="News")
@@ -183,7 +159,7 @@ async def test_removal_of_the_relations(cleanup):
 
 @pytest.mark.asyncio
 async def test_selecting_related(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = await Category.objects.create(name="News")
@@ -210,7 +186,7 @@ async def test_selecting_related(cleanup):
 
 @pytest.mark.asyncio
 async def test_selecting_related_fail_without_saving(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = Post(title="Hello, M2M", author=guido)
         with pytest.raises(RelationshipInstanceError):
@@ -219,7 +195,7 @@ async def test_selecting_related_fail_without_saving(cleanup):
 
 @pytest.mark.asyncio
 async def test_adding_unsaved_related(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = Category(name="News")
@@ -233,7 +209,7 @@ async def test_adding_unsaved_related(cleanup):
 
 @pytest.mark.asyncio
 async def test_removing_unsaved_related(cleanup):
-    async with database:
+    async with base_ormar_config.database:
         guido = await Author.objects.create(first_name="Guido", last_name="Van Rossum")
         post = await Post.objects.create(title="Hello, M2M", author=guido)
         news = Category(name="News")
