@@ -1,39 +1,30 @@
 # type: ignore
 
-import databases
-import pytest
-import sqlalchemy
-
 import ormar
+import pytest
 from ormar import ModelDefinitionError
-from tests.settings import DATABASE_URL
 
-database = databases.Database(DATABASE_URL, force_rollback=True)
-metadata = sqlalchemy.MetaData()
+from tests.lifespan import init_tests
+from tests.settings import create_config
+
+base_ormar_config = create_config()
 
 
 def test_through_with_relation_fails():
-    class BaseMeta(ormar.ModelMeta):
-        database = database
-        metadata = metadata
-
     class Category(ormar.Model):
-        class Meta(BaseMeta):
-            tablename = "categories"
+        ormar_config = base_ormar_config.copy(tablename="categories")
 
         id = ormar.Integer(primary_key=True)
         name = ormar.String(max_length=40)
 
     class Blog(ormar.Model):
-        class Meta(BaseMeta):
-            pass
+        ormar_config = base_ormar_config.copy()
 
         id: int = ormar.Integer(primary_key=True)
         title: str = ormar.String(max_length=200)
 
     class PostCategory(ormar.Model):
-        class Meta(BaseMeta):
-            tablename = "posts_x_categories"
+        ormar_config = base_ormar_config.copy(tablename="posts_x_categories")
 
         id: int = ormar.Integer(primary_key=True)
         sort_order: int = ormar.Integer(nullable=True)
@@ -43,9 +34,11 @@ def test_through_with_relation_fails():
     with pytest.raises(ModelDefinitionError):
 
         class Post(ormar.Model):
-            class Meta(BaseMeta):
-                pass
+            ormar_config = base_ormar_config.copy()
 
             id: int = ormar.Integer(primary_key=True)
             title: str = ormar.String(max_length=200)
             categories = ormar.ManyToMany(Category, through=PostCategory)
+
+
+create_test_database = init_tests(base_ormar_config)
