@@ -1,29 +1,24 @@
 from typing import Optional
 
-import databases
+import ormar
+import pydantic
 import pytest
 import pytest_asyncio
-import sqlalchemy
-
-import ormar
 from ormar import (
     post_relation_add,
     post_relation_remove,
     pre_relation_add,
     pre_relation_remove,
 )
-import pydantic
-from tests.settings import DATABASE_URL
 
-database = databases.Database(DATABASE_URL, force_rollback=True)
-metadata = sqlalchemy.MetaData()
+from tests.lifespan import init_tests
+from tests.settings import create_config
+
+base_ormar_config = create_config()
 
 
 class AuditLog(ormar.Model):
-    class Meta:
-        tablename = "audits"
-        metadata = metadata
-        database = database
+    ormar_config = base_ormar_config.copy(tablename="audits")
 
     id: int = ormar.Integer(primary_key=True)
     event_type: str = ormar.String(max_length=100)
@@ -31,30 +26,21 @@ class AuditLog(ormar.Model):
 
 
 class Cover(ormar.Model):
-    class Meta:
-        tablename = "covers"
-        metadata = metadata
-        database = database
+    ormar_config = base_ormar_config.copy(tablename="covers")
 
     id: int = ormar.Integer(primary_key=True)
     title: str = ormar.String(max_length=100)
 
 
 class Artist(ormar.Model):
-    class Meta:
-        tablename = "artists"
-        metadata = metadata
-        database = database
+    ormar_config = base_ormar_config.copy(tablename="artists")
 
     id: int = ormar.Integer(name="artist_id", primary_key=True)
     name: str = ormar.String(name="fname", max_length=100)
 
 
 class Album(ormar.Model):
-    class Meta:
-        tablename = "albums"
-        metadata = metadata
-        database = database
+    ormar_config = base_ormar_config.copy(tablename="albums")
 
     id: int = ormar.Integer(primary_key=True)
     title: str = ormar.String(max_length=100)
@@ -62,26 +48,20 @@ class Album(ormar.Model):
     artists = ormar.ManyToMany(Artist)
 
 
-@pytest.fixture(autouse=True, scope="module")
-def create_test_database():
-    engine = sqlalchemy.create_engine(DATABASE_URL)
-    metadata.drop_all(engine)
-    metadata.create_all(engine)
-    yield
-    metadata.drop_all(engine)
+create_test_database = init_tests(base_ormar_config)
 
 
 @pytest_asyncio.fixture(autouse=True, scope="function")
 async def cleanup():
     yield
-    async with database:
+    async with base_ormar_config.database:
         await AuditLog.objects.delete(each=True)
 
 
 @pytest.mark.asyncio
 async def test_relation_signal_functions():
-    async with database:
-        async with database.transaction(force_rollback=True):
+    async with base_ormar_config.database:
+        async with base_ormar_config.database.transaction(force_rollback=True):
 
             @pre_relation_add([Album, Cover, Artist])
             async def before_relation_add(
